summaryrefslogtreecommitdiffstats
path: root/src/simplemainwindow.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/simplemainwindow.cpp')
-rw-r--r--src/simplemainwindow.cpp36
1 files changed, 18 insertions, 18 deletions
diff --git a/src/simplemainwindow.cpp b/src/simplemainwindow.cpp
index 1f2c4dd5..e98ce01c 100644
--- a/src/simplemainwindow.cpp
+++ b/src/simplemainwindow.cpp
@@ -57,8 +57,8 @@
#include "editorproxy.h"
#include "multibuffer.h"
-SimpleMainWindow::SimpleMainWindow(TQWidget* tqparent, const char *name)
- :DMainWindow(tqparent, name)
+SimpleMainWindow::SimpleMainWindow(TQWidget* parent, const char *name)
+ :DMainWindow(parent, name)
{
resize(800, 600); // starts kdevelop at 800x600 the first time
m_mainWindowShare = new MainWindowShare(TQT_TQOBJECT(this));
@@ -322,15 +322,15 @@ void SimpleMainWindow::raiseView(TQWidget *view)
{
//adymo: a workaround to make editor wrappers work:
//editor view is passed to this function but the ui library knows only
//of its tqparent which is an editor wrapper, simply replacing the view
//by its wrapper helps here
- if (view->tqparent())
- kdDebug() << view->tqparent()->className() << endl;
- if (view->tqparent() && (view->tqparent()->isA("EditorWrapper") || view->tqparent()->isA("MultiBuffer")))
+ if (view->parent())
+ kdDebug() << view->parent()->className() << endl;
+ if (view->parent() && (view->parent()->isA("EditorWrapper") || view->parent()->isA("MultiBuffer")))
{
-// kdDebug() << "tqparent is editor wrapper: " <<
-// static_cast<EditorWrapper*>(view->tqparent()) << endl;
- view = (TQWidget*)view->tqparent();
+// kdDebug() << "parent is editor wrapper: " <<
+// static_cast<EditorWrapper*>(view->parent()) << endl;
+ view = (TQWidget*)view->parent();
}
if (hasDockWidget(view))
@@ -577,9 +577,9 @@ void SimpleMainWindow::documentChangedState(const KURL &url, DocumentState state
void SimpleMainWindow::closeTab()
{
// actionCollection()->action("file_close")->activate();
- if (TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()))->isA(TQTOOLBUTTON_OBJECT_NAME_STRING) && TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()))->tqparent()->isA("DTabWidget"))
+ if (TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()))->isA(TQTOOLBUTTON_OBJECT_NAME_STRING) && TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()))->parent()->isA("DTabWidget"))
{
- DTabWidget *tab = (DTabWidget*)TQT_TQWIDGET(const_cast<TQT_BASE_OBJECT_NAME*>(sender()))->tqparent();
+ DTabWidget *tab = (DTabWidget*)TQT_TQWIDGET(const_cast<TQT_BASE_OBJECT_NAME*>(sender()))->parent();
if (tab && tab->currentPage())
closeTab(tab->currentPage());
}
@@ -847,13 +847,13 @@ TQWidget *SimpleMainWindow::widgetForURL(KURL url)
TQWidget *SimpleMainWindow::widgetInTab(TQWidget *w)
{
TQWidget *inTab = 0;
- if (w && w->tqparent() && w->tqparent()->isA("EditorProxy"))
- inTab = (TQWidget*)w->tqparent();
- else if (w && w->tqparent() && w->tqparent()->isA("MultiBuffer")
- && w->tqparent()->tqparent() && w->tqparent()->tqparent()->isA("EditorProxy"))
- inTab = (TQWidget*)w->tqparent()->tqparent();
- else if (w && w->tqparent() && w->tqparent()->isA("MultiBuffer"))
- inTab = (TQWidget*)w->tqparent();
+ if (w && w->parent() && w->parent()->isA("EditorProxy"))
+ inTab = (TQWidget*)w->parent();
+ else if (w && w->parent() && w->parent()->isA("MultiBuffer")
+ && w->parent()->parent() && w->parent()->parent()->isA("EditorProxy"))
+ inTab = (TQWidget*)w->parent()->parent();
+ else if (w && w->parent() && w->parent()->isA("MultiBuffer"))
+ inTab = (TQWidget*)w->parent();
else
inTab = w;
return inTab;
@@ -322,15 +322,15 @@ void SimpleMainWindow::raiseView(TQWidget *view)
//adymo: a workaround to make editor wrappers work:
//editor view is passed to this function but the ui library knows only
- //of its tqparent which is an editor wrapper, simply replacing the view
+ //of its parent which is an editor wrapper, simply replacing the view
//by its wrapper helps here